summary refs log tree commit diff
path: root/.buildkite/scripts/test_old_deps.sh
diff options
context:
space:
mode:
authorAndrew Morgan <andrew@amorgan.xyz>2021-04-09 01:44:57 +0100
committerAndrew Morgan <andrew@amorgan.xyz>2021-04-09 01:44:57 +0100
commit0de0fe0fe72bb2e2e0044908b9b89fe489bdff5c (patch)
tree0c8a3541b2797e8055c8b171cde8d57fcba79227 /.buildkite/scripts/test_old_deps.sh
parentChangelog (diff)
parentBugbear: Add Mutable Parameter fixes (#9682) (diff)
downloadsynapse-0de0fe0fe72bb2e2e0044908b9b89fe489bdff5c.tar.xz
Merge branch 'develop' of github.com:matrix-org/synapse into anoa/allow_admins_delist_as_rooms
Diffstat (limited to '.buildkite/scripts/test_old_deps.sh')
-rwxr-xr-x.buildkite/scripts/test_old_deps.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/.buildkite/scripts/test_old_deps.sh b/.buildkite/scripts/test_old_deps.sh
index 9fe5b696b0..9270d55f04 100755
--- a/.buildkite/scripts/test_old_deps.sh
+++ b/.buildkite/scripts/test_old_deps.sh
@@ -1,16 +1,16 @@
 #!/usr/bin/env bash
 
 # this script is run by buildkite in a plain `xenial` container; it installs the
 # minimal requirements for tox and hands over to the py35-old tox environment.
 
 set -ex
 
 apt-get update
-apt-get install -y python3.5 python3.5-dev python3-pip libxml2-dev libxslt-dev xmlsec1 zlib1g-dev tox
+apt-get install -y python3 python3-dev python3-pip libxml2-dev libxslt-dev xmlsec1 zlib1g-dev tox
 
 export LANG="C.UTF-8"
 
 # Prevent virtualenv from auto-updating pip to an incompatible version
 export VIRTUALENV_NO_DOWNLOAD=1
 
-exec tox -e py35-old,combine
+exec tox -e py3-old,combine
@@ -1,16 +1,16 @@
 #!/usr/bin/env bash
 
-# this script is run by buildkite in a plain `xenial` container; it installs the
-# minimal requirements for tox and hands over to the py35-old tox environment.
+# this script is run by buildkite in a plain `bionic` container; it installs the
+# minimal requirements for tox and hands over to the py3-old tox environment.
 
 set -ex